==> lsof_3.43_W.tar.gz: lsof_3.43/dialects/hpux/dproto.h <==
/*
 * dproto.h - HP-UX function prototypes for lsof
 *
 * The _PROTOTYPE macro is defined in the common proto.h.
 */


/*
 * Copyright 1994 Purdue Research Foundation, West Lafayette, Indiana
 * 47907.  All rights reserved.
 *
 * Written by Victor A. Abell
 *
 * This software is not subject to any license of the American Telephone
 * and Telegraph Company or the Regents of the University of California.
 *
 * Permission is granted to anyone to use this software for any purpose on
 * any computer system, and to alter it and redistribute it freely, subject
 * to the following restrictions:
 *
 * 1. Neither the authors nor Purdue University are responsible for any
 *    consequences of the use of this software.
 *
 * 2. The origin of this software must not be misrepresented, either by
 *    explicit claim or by omission.  Credit to the authors and Purdue
 *    University must appear in documentation and sources.
 *
 * 3. Altered versions must be plainly marked as such, and must not be
 *    misrepresented as being the original software.
 *
 * 4. This notice may not be removed or altered.
 */


#if	_HPUXV>=800
_PROTOTYPE(extern void completevfs,(struct l_vfs *vfs, dev_t *dev, struct vfs *v));
#else
_PROTOTYPE(extern void completevfs,(struct l_vfs *vfs, dev_t *dev));
#endif	/* _HPUXV>=800 */

_PROTOTYPE(extern int is_file_named,(char *p, enum vtype ty));

#if	defined(DTYPE_LLA)
_PROTOTYPE(extern void process_lla,(caddr_t la));
#endif

_PROTOTYPE(extern struct l_vfs *readvfs,(struct vfs *ka, struct vfs *la));

==> lsof_3.45_W.tar.gz: lsof_3.45/dialects/hpux/dproto.h <==
/*
 * dproto.h - HP-UX function prototypes for lsof
 *
 * The _PROTOTYPE macro is defined in the common proto.h.
 */


/*
 * Copyright 1994 Purdue Research Foundation, West Lafayette, Indiana
 * 47907.  All rights reserved.
 *
 * Written by Victor A. Abell
 *
 * This software is not subject to any license of the American Telephone
 * and Telegraph Company or the Regents of the University of California.
 *
 * Permission is granted to anyone to use this software for any purpose on
 * any computer system, and to alter it and redistribute it freely, subject
 * to the following restrictions:
 *
 * 1. Neither the authors nor Purdue University are responsible for any
 *    consequences of the use of this software.
 *
 * 2. The origin of this software must not be misrepresented, either by
 *    explicit claim or by omission.  Credit to the authors and Purdue
 *    University must appear in documentation and sources.
 *
 * 3. Altered versions must be plainly marked as such, and must not be
 *    misrepresented as being the original software.
 *
 * 4. This notice may not be removed or altered.
 */


#if	_HPUXV>=800
_PROTOTYPE(extern void completevfs,(struct l_vfs *vfs, dev_t *dev, struct vfs *v));
#else
_PROTOTYPE(extern void completevfs,(struct l_vfs *vfs, dev_t *dev));
#endif	/* _HPUXV>=800 */

_PROTOTYPE(extern int is_file_named,(char *p, enum vtype ty));

#if	defined(DTYPE_LLA)
_PROTOTYPE(extern void process_lla,(caddr_t la));
#endif

_PROTOTYPE(extern struct l_vfs *readvfs,(struct vfs *ka, struct vfs *la));

#if	defined(HASVXFS)
_PROTOTYPE(extern int read_vxnode,(struct vnode *v, struct l_vfs *vfs, dev_t *dev));
#endif	/* defined(HASVXFS) */
